==> MediaWikiLanguageExtensionBundle-2015.08.tar.bz2: extensions/cldr/CldrNames/CldrNamesBo.php <==
<?php

$languageNames = array(
	'bn' => 'བྷང་ག་ལའི་སྐད།',
	'bo' => 'བོད་སྐད་',
	'da' => 'ཏེན་མག་གི་སྐད།',
	'de' => 'འཇར་མན་གྱི།',
	'dz' => 'རྫོང་ཁ',
	'en' => 'དབིན་ཇིའི་སྐད།',
	'en-ca' => 'དབིན་ཇིའི་སྐད། (ཁེ་ན་ཌ་)',
	'en-gb' => 'དབིན་ཇིའི་སྐད། (དབིན་ཇིའི་རྒྱལ་ཁབ་)',
	'en-us' => 'དབིན་ཇིའི་སྐད། (ཨ་རི་)',
	'es' => 'ཞི་པན་ཡའི།',
	'fr' => 'ཧྥ་རན་སིའི་།',
	'gaa' => 'གཱ་སྐད།',
	'gu' => 'གུཇ་རཱཏི་སྐད།',
	'hi' => 'ཧིན་དི',
	'id' => 'ཨིན་དོ་ནི་སི་སྐད།',
	'it' => 'དབྱི་ཏ་་ལའི་མི།',
	'ja' => 'རི་པིན་སྐད་',
	'kn' => 'ཀནྣ་ཌ་སྐད།',
	'ko' => 'ཁོ་རེ་ཡའི་སྐད།',
	'la' => 'ལཱ་ཏིན་སྐད།',
	'mn' => 'སོག་སྐད།',
	'mr' => 'མ་ར་ཐི་སྐད།',
	'ms' => 'མ་ལ་ཡ་སྐད།',
	'my' => 'འབར་མའི་སྐད།',
	'ne' => 'ནེ་པ་ལི',
	'nl' => 'ཧའོ་ལན་སྐད།',
	'nn' => 'ནོ་ཝེ་སྐད།',
	'or' => 'ཨཽ་རི་ཡ་སྐད།',
	'pl' => 'པོ་ལན་སྐད།',
	'pt' => 'ཕི་ཐོ་ཡའི།',
	'pt-br' => 'པ་ཞའི་མི། ཕི་ཐོ་ཡའི་མི།',
	'ru' => 'ཨུ་རུ་སུ་སྐད་',
	'sa' => 'སཾ་སྐྲྀ་ཏ།',
	'si' => 'ཞི་ལན་སྐད།',
	'sv' => 'ཧྲུའི་ཏན་སྐད།',
	'ta' => 'ཏཱ་མིལ་སྐད།',
	'te' => 'ཏེ་ལུ་གུ་སྐད།',
	'th' => 'ཐའའི་ཡུལ་སྐད།',
	'tr' => 'ཐུར་ཁེའི་སྐད།',
	'ug' => 'ཡུ་གུར་སྐད།',
	'uk' => 'ཡུ་ཀྲ་ནི་སྐད།',
	'und' => 'མིའི་ཤེས་རྟོགས་མ་བྱུང་བ། ཡང་ན་ཆད་ལྷག་ཅན་གྱི་སྐད་བརྡ།',
	'ur' => 'ཝུའུ་ཏུའུ་སྐད།',
	'vi' => 'ཡོ་ནན་སྐད།',
	'zen' => 'ཟེ་ན་གཱ་སྐད།',
	'zh' => 'རྒྱ་སྐད་',
	'zh-hans' => 'སྟབས་བརྡའི། ཀྲུང་གོའི།',
	'zh-hant' => 'སྲོལ་རྒྱུན་གྱི།',
	'zu' => 'ཟུ་ལུ་སྐད།',
	'zun' => 'ཟུ་ནི་སྐད།',
	'zza' => 'ཟ་ཟཱ་སྐད།',
);

$currencyNames = array(
	'CNY' => 'ཡུ་ཨན་',
	'INR' => 'རྒྱ་གར་སྒོར་མོ་',
	'USD' => 'ཨ་རིའི་སྒོར་མོ།',
	'XXX' => 'མ་རྟོགས་པའི་ནུས་མེད་དངུལ་ལོར',
);

$currencySymbols = array(
	'CNY' => '¥',
);

$countryNames = array(
	'AD' => 'ཨེན་ཌོ་ར།',
	'AE' => 'ཨ་རབ། ཨི་མི་རཊ྄། ཆིག་སྒྲིལ་རྒྱལ་ཁབ།',
	'AF' => 'ཨཕ་ག་ནི་སྟཱན།',
	'AG' => 'ཨེན་ཊི་གུ་དང་། བྷར་བུ་ཌ།',
	'AI' => 'ཨང་གུའི་ལ།',
	'AL' => 'ཨལ་བཱ་ནི་ཡ།',
	'AM' => 'ཨར་མེ་ནི་ཡ།',
	'AO' => 'ཨང་གཽ་ལ།',
	'AQ' => 'ལྷོ་རྩེའི་མཐའ་གླིང་།',
	'AR' => 'ཨར་ཇེན་ཊི་ན།',
	'AT' => 'ཨསྟྲི་ཡ།',
	'AU' => 'ཨསྟྲེ་ལི་ཡ།',
	'AW' => 'ཨ་རུ་བ།',
	'AZ' => 'ཨཛར་བཡེ་ཇན།',
	'BA' => 'བོསྣི་ཡ་དང་ཧརྫོ་གོ་ཝི་ན།',
	'BB' => 'བཱརྦ་ཌོས྄།',
	'BD' => 'བངྒ་ལ་དེཤ།',
	'BE' => 'བེལ་ཇི་ཡམ།',
	'BF' => 'བརཀི་ན། ཕསོ།',
	'BG' => 'བུལ་ག་རི་ཡ།',
	'BH' => 'བྷཱ་རེན།',
	'BI' => 'བུ་རུན་ཌི།',
	'BJ' => 'བཱེ་ནིན།',
	'BM' => 'བར་མུ་ཌ།',
	'BN' => 'བུ་རུ་ནེ།',
	'BO' => 'བོ་ལི་ཝིཡ།',
	'BR' => 'བ་རཱ་ཛིལ།',
	'BS' => 'བྷཱ་མས྄།',
	'BT' => 'འབྲུག་ཡུལ།',
	'BW' => 'བོཙ་ཝ་ན།',
	'BY' => 'བེ་ལུ་རུ་སུ།',
	'BZ' => 'བེ་ལིཛ།',
	'CA' => 'ཁེ་ན་ཌ།',
	'CH' => 'ཧྲུད་ཧྲི།',
	'CI' => 'ཀོ་ཊེ་ཌི། ཨི་ཝོ་རེ།',
	'CK' => 'ཀཱུག གླིང་ཕྲེན་རྒྱལ་ཁབ།',
	'CL' => 'ཅི་ལི།',
	'CM' => 'ཀ་མེ་རུན།',
	'CN' => 'རྒྱ་ནག',
	'CO' => 'ཀོ་ལོམ་བི་ཡ།',
	'CR' => 'ཀོ་ས྄ཊ་རི་ཀ།',
	'CU' => 'ཁྱུའུ་བ།',
	'CY' => 'སཱཡེ་པ་རས྄།',
	'CZ' => 'ཅཻག་སྤྱི་མཐུན་རྒྱལ་ཁབ།',
	'DE' => 'འཇར་མན་',
	'DJ' => 'ཛི་བུ་ཏི།',
	'DK' => 'ཌེན་མཱརྐ།',
	'DM' => 'ཌོ་མིན་ནི་ཀ།',
	'DO' => 'ཌོ་མིནནི་ཀན་སྤྱི་མཐུན་རྒྱལ་ཁབ།',
	'DZ' => 'ཨལ་ཇི་རི་ཡ།',
	'EC' => 'ཨི་ཁྭ་ཌོར།',
	'EE' => 'ཨིསྟོ་ནི་ཡ།',
	'EG' => 'ཨི་ཇིབྚ།',
	'ER' => 'ཨེ་རི་ཏྲེ་ཨ།',
	'ES' => 'སི་པན།',
	'ET' => 'ཨི་ཐིའོ་པི་ཡ།',
	'FI' => 'ཕིན་ལན྄ཌ།',
	'FJ' => 'ཕི་ཇི།',
	'FK' => 'ཕལྐ་ལནྜ་གླིང་ཕྲན།',
	'FR' => 'ཕ་རཱན་སི།',
	'GA' => 'གེ་བཽན།',
	'GB' => 'དབྱིན་ཇི་',
	'GD' => 'གྷ་རི་ན་ཌ།',
	'GE' => 'ཇོར་ཇི་ཡ།',
	'GH' => 'གྷ་ན།',
	'GI' => 'ཇིབ་རཱལ་ཊར།',
	'GM' => 'གྷམ་བི་ཡ།',
	'GN' => 'གྷི་ནི་ཡ།',
	'GR' => 'གྷི་རཱི་སི།',
	'GT' => 'གྷོ་ཊེ་མ་ལ།',
	'GW' => 'གྷི་ནི་ཡ་བིས྄་སོ།',
	'GY' => 'གྷུ་ཡཱ་ན།',
	'HK' => 'ཧོང་ཀོང༌།',
	'HN' => 'ཧོན་དུ་རས྄།',
	'HR' => 'ཀུརོ་ཤི་ཡ།',
	'HT' => 'ཧེ་ཏི།',
	'HU' => 'ཧངྒ་རི།',
	'ID' => 'ཨིན་ཌོ་ནེ་ཤི་ཡ།',
	'IE' => 'ཨ་ཡར་ལནཌ།',
	'IL' => 'ཨི་ཛ྄་རེལ།',
	'IN' => 'རྒྱ་གར་',
	'IQ' => 'ཨི་རག།',
	'IR' => 'ཨི་རཱན།',
	'IS' => 'ཨ་ཨི་སི་ལནད།',
	'IT' => 'ཨི་ཀྲར་ལི་',
	'JM' => 'ཛ་མེ་ཀ།',
	'JO' => 'ཇོར་ཌན།',
	'JP' => 'རི་པིན་',
	'KE' => 'ཁེན་ཉི་ཡ།',
	'KG' => 'ཁིར་གིཛ་སྟཱན།',
	'KH' => 'ཀམ་བོ་ཌི་ཡ།',
	'KI' => 'ཀི་རི་བཱ་ཏི།',
	'KN' => 'སེནྚ། ཀིཊྚས྄། དང༌། ནེ་བིས྄།',
	'KR' => 'ཀོ་རི་ཡ། ལྷོ་མ།',
	'KW' => 'ཀུ་ཝེད་རྒྱལ་ཁབ།',
	'KY' => 'ཁེ་མེན་གླིང་ཕྲན།',
	'KZ' => 'ཁ་ཛཱག་སྟཱན།',
	'LA' => 'ལཱ་འོས།',
	'LB' => 'ལེབ་ནོན།',
	'LC' => 'སེནྚ། ལུ་ཤི་ཡ།',
	'LI' => 'ལེག་ཏེན་ཚིན།',
	'LK' => 'ཤྲཱི་ལངྐ་།',
	'LR' => 'ལི་བེ་རི་ཡ།',
	'LS' => 'ལེ་སོ་ཐོ།',
	'LT' => 'ལི་ཐུ་ཨེ་ནི་ཡ།',
	'LU' => 'ལཀ་ཛམ་བོརྒ།',
	'LV' => 'ལཏ་བི་ཡ།',
	'LY' => 'ལི་བི་ཡ།',
	'MA' => 'མོ་རོ་ཀྐོ།',
	'MC' => 'མོ་ན་ཀོ།',
	'MG' => 'མ་དཱ་གྷསྐཱར།',
	'MH' => 'མཱར་ཤལ་གླིང་ཕྲེན།',
	'ML' => 'མ་ལི།',
	'MM' => 'འབར་མ།',
	'MN' => 'སོག་ཡུལ།',
	'MO' => 'མེ་ཀའོ།',
	'MR' => 'མཽ་རི་ཏ་ནི་ཡ།',
	'MT' => 'མལ་ཊ།',
	'MU' => 'མཽ་རིཤས྄།',
	'MV' => 'མལ་དྭིབ།',
	'MW' => 'མཱ་ལཱ་ཝི།',
	'MX' => 'མེཀ་སི་ཀོ།',
	'MY' => 'མ་ལེ་ཤི་ཡ།',
	'MZ' => 'མོ་ཛམ་བིག།',
	'NA' => 'ན་མི་བི་ཡ།',
	'NE' => 'ནའི་ཇར།',
	'NG' => 'ནཱའི་ཇི་རི་ཡ།',
	'NI' => 'ནི་ཀ་ར་གུ་ཨ།',
	'NL' => 'ཧའོ་ལན།',
	'NO' => 'ནོར་ཝེ།',
	'NP' => 'བར་ཡུལ་',
	'NR' => 'ནཽ་རུ།',
	'NU' => 'ནིའུ་ཝ།',
	'NZ' => 'ནིའུ་ཛི་ལན྄ཌ།',
	'OM' => 'ཨོ་མན།',
	'PA' => 'པ་ནཱ་མ།',
	'PE' => 'པེ་རུ།',
	'PG' => 'པ་པུ་ཨ། ནིའུ། གྷི་ནི།',
	'PH' => 'ཕི་ལི་པིནས྄།',
	'PK' => 'པཀི་སྟཱན།',
	'PL' => 'པོ་ལནྜ།',
	'PT' => 'པོར་ཏུ་གྷལ།',
	'PW' => 'པ་ལཽ།',
	'PY' => 'པཱ་ར་གེ།',
	'QA' => 'ཀ་ཏཱར།',
	'RO' => 'རོ་མཱ་ནིཡ།',
	'RS' => 'སེར་བི་ཡ།',
	'RU' => 'ཨུ་རུ་སུ་',
	'RW' => 'རུ་ཝན་ཌ།',
	'SA' => 'སཽ་དྷི་ཨ་རཱ་བི་ཡ།',
	'SB' => 'སོ་ལོ་མོན། གླིང་ཕྲན་ཚོ་ཁག།',
	'SC' => 'སཱ་ཤཻལ།',
	'SD' => 'སུ་དཱན།',
	'SE' => 'ཧྲུའི་ཏན།',
	'SG' => 'སིངྒ་པུར།',
	'SH' => 'སེནྚ། ཧེ་ལི་ན།',
	'SI' => 'ས་ལཽ་ཝེ་ནི་ཡ།',
	'SK' => 'ས་ལཽ་ཝཀྱ།',
	'SL' => 'སེ་ཡར་ར། ལིའོན།',
	'SM' => 'སན་མེ་རི་ནོ།',
	'SN' => 'སེ་ནི་གྷལ།',
	'SO' => 'སོ་མཱལི་ཡ།',
	'SR' => 'སུ་རི་ནཱམ།',
	'ST' => 'ས་འོ་ཏོད་མད། དང༌། པ྄རིན་སི་པེ།',
	'SV' => 'ཨེལ། སཱལ་ཝ་ཌོར།',
	'TD' => 'ཅཻཌ།',
	'TR' => 'ཏུརཀི།',
	'TV' => 'ཐུ་ཝ་ལུ།',
	'UA' => 'ཡུ་ཀྲན།',
	'UG' => 'ཡུ་གན་ཌ།',
	'US' => 'ཨ་མེ་རི་ཀ།',
	'UY' => 'ཨུ་རུ་གྷེ།',
	'UZ' => 'ཨུཛ་བེ་ཀིསྟཱན།',
	'VA' => 'ཝེ་ཊི་ཀན།',
	'VC' => 'སེནྚ། ཝིན་སན། དང༌། གྷིརིན་ཌིན།',
	'VE' => 'ཝེ་ནི་ཛུའེ་ལ།',
	'VN' => 'བི་དི་ནམ།',
	'VU' => 'ཝ་ནུ་ཨ་ཐུ།',
	'WS' => 'ནུ་བ་ས་མོ་འ།',
	'YE' => 'ཡེ་མེན།',
	'ZA' => 'ལྷོ་ ཨཕྲི་ཀ།',
	'ZM' => 'ཛམ་བི་ཡ།',
	'ZW' => 'ཛིམ་བྷཱ་བེ།',
);

==> MediaWikiLanguageExtensionBundle-2016.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesBo.php <==
<?php

$languageNames = array(
	'bn' => 'བྷང་ག་ལའི་སྐད།',
	'bo' => 'བོད་སྐད་',
	'da' => 'ཏེན་མག་གི་སྐད།',
	'de' => 'འཇར་མན་གྱི།',
	'dz' => 'རྫོང་ཁ',
	'en' => 'དབྱིན་ཇིའི་སྐད།',
	'en-ca' => 'དབྱིན་ཇིའི་སྐད། (ཁེ་ན་ཌ་)',
	'en-gb' => 'དབྱིན་ཇིའི་སྐད། (དབྱིན་ལན་)',
	'en-us' => 'དབྱིན་ཇིའི་སྐད། (ཨ་རི་)',
	'es' => 'ཞི་པན་ཡའི།',
	'fr' => 'ཧྥ་རན་སིའི་།',
	'gaa' => 'གཱ་སྐད།',
	'gu' => 'གུཇ་རཱཏི་སྐད།',
	'hi' => 'ཧིན་དི',
	'id' => 'ཨིན་དོ་ནི་སི་སྐད།',
	'it' => 'དབྱི་ཏ་་ལའི་མི།',
	'ja' => 'ཉི་ཧོང་སྐད་',
	'kn' => 'ཀནྣ་ཌ་སྐད།',
	'ko' => 'ཁོ་རེ་ཡའི་སྐད།',
	'la' => 'ལཱ་ཏིན་སྐད།',
	'mn' => 'སོག་སྐད།',
	'mr' => 'མ་ར་ཐི་སྐད།',
	'ms' => 'མ་ལ་ཡ་སྐད།',
	'my' => 'འབར་མའི་སྐད།',
	'ne' => 'ནེ་པ་ལི',
	'nl' => 'ཧའོ་ལན་སྐད།',
	'nn' => 'ནོ་ཝེ་སྐད།',
	'or' => 'ཨཽ་རི་ཡ་སྐད།',
	'pl' => 'པོ་ལན་སྐད།',
	'pt' => 'ཕི་ཐོ་ཡའི།',
	'pt-br' => 'པ་ཞའི་མི། ཕི་ཐོ་ཡའི་མི།',
	'ru' => 'ཨུ་རུ་སུ་སྐད་',
	'sa' => 'སཾ་སྐྲྀ་ཏ།',
	'si' => 'ཞི་ལན་སྐད།',
	'sv' => 'ཧྲུའི་ཏན་སྐད།',
	'ta' => 'ཏཱ་མིལ་སྐད།',
	'te' => 'ཏེ་ལུ་གུ་སྐད།',
	'th' => 'ཐའའི་ཡུལ་སྐད།',
	'tr' => 'ཐུར་ཁེའི་སྐད།',
	'ug' => 'ཡུ་གུར་སྐད།',
	'uk' => 'ཡུ་ཀྲ་ནི་སྐད།',
	'und' => 'མིའི་ཤེས་རྟོགས་མ་བྱུང་བ། ཡང་ན་ཆད་ལྷག་ཅན་གྱི་སྐད་བརྡ།',
	'ur' => 'ཝུའུ་ཏུའུ་སྐད།',
	'vi' => 'ཡོ་ནན་སྐད།',
	'zen' => 'ཟེ་ན་གཱ་སྐད།',
	'zh' => 'རྒྱ་སྐད་',
	'zh-hans' => 'སྟབས་བརྡའི། ཀྲུང་གོའི།',
	'zh-hant' => 'སྲོལ་རྒྱུན་གྱི།',
	'zu' => 'ཟུ་ལུ་སྐད།',
	'zun' => 'ཟུ་ནི་སྐད།',
	'zza' => 'ཟ་ཟའ་སྐད།',
);

$currencyNames = array(
	'CNY' => 'ཡུ་ཨན་',
	'INR' => 'རྒྱ་གར་སྒོར་',
	'USD' => 'ཨ་རིའི་སྒོར་',
	'XXX' => 'མ་རྟོགས་པའི་ནུས་མེད་དངུལ་ལོར',
);

$currencySymbols = array(
	'CNY' => '¥',
);

$countryNames = array(
	'AD' => 'ཨེན་ཌོ་ར།',
	'AE' => 'ཨ་རབ། ཨི་མི་རཊ྄། ཆིག་སྒྲིལ་རྒྱལ་ཁབ།',
	'AF' => 'ཨཕ་ག་ནི་སྟཱན།',
	'AG' => 'ཨེན་ཊི་གུ་དང་། བྷར་བུ་ཌ།',
	'AI' => 'ཨང་གུའི་ལ།',
	'AL' => 'ཨལ་བཱ་ནི་ཡ།',
	'AM' => 'ཨར་མེ་ནི་ཡ།',
	'AO' => 'ཨང་གཽ་ལ།',
	'AQ' => 'ལྷོ་རྩེའི་མཐའ་གླིང་།',
	'AR' => 'ཨར་ཇེན་ཊི་ན།',
	'AT' => 'ཨསྟྲི་ཡ།',
	'AU' => 'ཨསྟྲེ་ལི་ཡ།',
	'AW' => 'ཨ་རུ་བ།',
	'AZ' => 'ཨཛར་བཡེ་ཇན།',
	'BA' => 'བོསྣི་ཡ་དང་ཧརྫོ་གོ་ཝི་ན།',
	'BB' => 'བཱརྦ་ཌོས྄།',
	'BD' => 'བངྒ་ལ་དེཤ།',
	'BE' => 'བེལ་ཇི་ཡམ།',
	'BF' => 'བརཀི་ན། ཕསོ།',
	'BG' => 'བུལ་ག་རི་ཡ།',
	'BH' => 'བྷཱ་རེན།',
	'BI' => 'བུ་རུན་ཌི།',
	'BJ' => 'བཱེ་ནིན།',
	'BM' => 'བར་མུ་ཌ།',
	'BN' => 'བུ་རུ་ནེ།',
	'BO' => 'བོ་ལི་ཝིཡ།',
	'BR' => 'བ་རཱ་ཛིལ།',
	'BS' => 'བྷཱ་མས྄།',
	'BT' => 'འབྲུག་ཡུལ།',
	'BW' => 'བོཙ་ཝ་ན།',
	'BY' => 'བེ་ལུ་རུ་སུ།',
	'BZ' => 'བེ་ལིཛ།',
	'CA' => 'ཁེ་ན་ཌ།',
	'CH' => 'ཧྲུད་ཧྲི།',
	'CI' => 'ཀོ་ཊེ་ཌི། ཨི་ཝོ་རེ།',
	'CK' => 'ཀཱུག གླིང་ཕྲེན་རྒྱལ་ཁབ།',
	'CL' => 'ཅི་ལི།',
	'CM' => 'ཀ་མེ་རུན།',
	'CN' => 'རྒྱ་ནག',
	'CO' => 'ཀོ་ལོམ་བི་ཡ།',
	'CR' => 'ཀོ་ས྄ཊ་རི་ཀ།',
	'CU' => 'ཁྱུའུ་བ།',
	'CY' => 'སཱཡེ་པ་རས྄།',
	'CZ' => 'ཅཻག་སྤྱི་མཐུན་རྒྱལ་ཁབ།',
	'DE' => 'འཇར་མན་',
	'DJ' => 'ཛི་བུ་ཏི།',
	'DK' => 'ཌེན་མཱརྐ།',
	'DM' => 'ཌོ་མིན་ནི་ཀ།',
	'DO' => 'ཌོ་མིནནི་ཀན་སྤྱི་མཐུན་རྒྱལ་ཁབ།',
	'DZ' => 'ཨལ་ཇི་རི་ཡ།',
	'EC' => 'ཨི་ཁྭ་ཌོར།',
	'EE' => 'ཨིསྟོ་ནི་ཡ།',
	'EG' => 'ཨི་ཇིབྚ།',
	'ER' => 'ཨེ་རི་ཏྲེ་ཨ།',
	'ES' => 'སི་པན།',
	'ET' => 'ཨི་ཐིའོ་པི་ཡ།',
	'FI' => 'ཕིན་ལན྄ཌ།',
	'FJ' => 'ཕི་ཇི།',
	'FK' => 'ཕལྐ་ལནྜ་གླིང་ཕྲན།',
	'FR' => 'ཕ་རཱན་སི།',
	'GA' => 'གེ་བཽན།',
	'GB' => 'དབྱིན་ཇི་',
	'GD' => 'གྷ་རི་ན་ཌ།',
	'GE' => 'ཇོར་ཇི་ཡ།',
	'GH' => 'གྷ་ན།',
	'GI' => 'ཇིབ་རཱལ་ཊར།',
	'GM' => 'གྷམ་བི་ཡ།',
	'GN' => 'གྷི་ནི་ཡ།',
	'GR' => 'གྷི་རཱི་སི།',
	'GT' => 'གྷོ་ཊེ་མ་ལ།',
	'GW' => 'གྷི་ནི་ཡ་བིས྄་སོ།',
	'GY' => 'གྷུ་ཡཱ་ན།',
	'HK' => 'ཧོང་ཀོང༌།',
	'HN' => 'ཧོན་དུ་རས྄།',
	'HR' => 'ཀུརོ་ཤི་ཡ།',
	'HT' => 'ཧེ་ཏི།',
	'HU' => 'ཧངྒ་རི།',
	'ID' => 'ཨིན་ཌོ་ནེ་ཤི་ཡ།',
	'IE' => 'ཨ་ཡར་ལནཌ།',
	'IL' => 'ཨི་ཛ྄་རེལ།',
	'IN' => 'རྒྱ་གར་',
	'IQ' => 'ཨི་རག།',
	'IR' => 'ཨི་རཱན།',
	'IS' => 'ཨ་ཨི་སི་ལནད།',
	'IT' => 'ཨི་ཀྲར་ལི་',
	'JM' => 'ཛ་མེ་ཀ།',
	'JO' => 'ཇོར་ཌན།',
	'JP' => 'ཉི་ཧོང་',
	'KE' => 'ཁེན་ཉི་ཡ།',
	'KG' => 'ཁིར་གིཛ་སྟཱན།',
	'KH' => 'ཀམ་བོ་ཌི་ཡ།',
	'KI' => 'ཀི་རི་བཱ་ཏི།',
	'KN' => 'སེནྚ། ཀིཊྚས྄། དང༌། ནེ་བིས྄།',
	'KR' => 'ལྷོ་ཀོ་རི་ཡ།',
	'KW' => 'ཀུ་ཝེད་རྒྱལ་ཁབ།',
	'KY' => 'ཁེ་མེན་གླིང་ཕྲན།',
	'KZ' => 'ཁ་ཛཱག་སྟཱན།',
	'LA' => 'ལཱ་འོས།',
	'LB' => 'ལེབ་ནོན།',
	'LC' => 'སེནྚ། ལུ་ཤི་ཡ།',
	'LI' => 'ལེག་ཏེན་ཚིན།',
	'LK' => 'ཤྲཱི་ལངྐ་།',
	'LR' => 'ལི་བེ་རི་ཡ།',
	'LS' => 'ལེ་སོ་ཐོ།',
	'LT' => 'ལི་ཐུ་ཨེ་ནི་ཡ།',
	'LU' => 'ལཀ་ཛམ་བོརྒ།',
	'LV' => 'ལཏ་བི་ཡ།',
	'LY' => 'ལི་བི་ཡ།',
	'MA' => 'མོ་རོ་ཀྐོ།',
	'MC' => 'མོ་ན་ཀོ།',
	'MG' => 'མ་དཱ་གྷསྐཱར།',
	'MH' => 'མཱར་ཤལ་གླིང་ཕྲེན།',
	'ML' => 'མ་ལི།',
	'MM' => 'འབར་མ།',
	'MN' => 'སོག་ཡུལ།',
	'MO' => 'མེ་ཀའོ།',
	'MR' => 'མཽ་རི་ཏ་ནི་ཡ།',
	'MT' => 'མལ་ཊ།',
	'MU' => 'མཽ་རིཤས྄།',
	'MV' => 'མལ་དྭིབ།',
	'MW' => 'མཱ་ལཱ་ཝི།',
	'MX' => 'མེཀ་སི་ཀོ།',
	'MY' => 'མ་ལེ་ཤི་ཡ།',
	'MZ' => 'མོ་ཛམ་བིག།',
	'NA' => 'ན་མི་བི་ཡ།',
	'NE' => 'ནའི་ཇར།',
	'NG' => 'ནཱའི་ཇི་རི་ཡ།',
	'NI' => 'ནི་ཀ་ར་གུ་ཨ།',
	'NL' => 'ཧའོ་ལན།',
	'NO' => 'ནོར་ཝེ།',
	'NP' => 'བལ་ཡུལ་',
	'NR' => 'ནཽ་རུ།',
	'NU' => 'ནིའུ་ཝ།',
	'NZ' => 'ནིའུ་ཛི་ལན྄ཌ།',
	'OM' => 'ཨོ་མན།',
	'PA' => 'པ་ནཱ་མ།',
	'PE' => 'པེ་རུ།',
	'PG' => 'པ་པུ་ཨ། ནིའུ། གྷི་ནི།',
	'PH' => 'ཕི་ལི་པིནས྄།',
	'PK' => 'པཀི་སྟཱན།',
	'PL' => 'པོ་ལནྜ།',
	'PT' => 'པོར་ཏུ་གྷལ།',
	'PW' => 'པ་ལཽ།',
	'PY' => 'པཱ་ར་གེ།',
	'QA' => 'ཀ་ཏཱར།',
	'RO' => 'རོ་མཱ་ནིཡ།',
	'RS' => 'སེར་བི་ཡ།',
	'RU' => 'ཨུ་རུ་སུ་',
	'RW' => 'རུ་ཝན་ཌ།',
	'SA' => 'སཽ་དྷི་ཨ་རཱ་བི་ཡ།',
	'SB' => 'སོ་ལོ་མོན། གླིང་ཕྲན་ཚོ་ཁག།',
	'SC' => 'སཱ་ཤཻལ།',
	'SD' => 'སུ་དཱན།',
	'SE' => 'ཧྲུའི་ཏན།',
	'SG' => 'སིངྒ་པུར།',
	'SH' => 'སེནྚ། ཧེ་ལི་ན།',
	'SI' => 'ས་ལཽ་ཝེ་ནི་ཡ།',
	'SK' => 'ས་ལཽ་ཝཀྱ།',
	'SL' => 'སེ་ཡར་ར། ལིའོན།',
	'SM' => 'སན་མེ་རི་ནོ།',
	'SN' => 'སེ་ནི་གྷལ།',
	'SO' => 'སོ་མཱལི་ཡ།',
	'SR' => 'སུ་རི་ནཱམ།',
	'ST' => 'ས་འོ་ཏོད་མད། དང༌། པ྄རིན་སི་པེ།',
	'SV' => 'ཨེལ། སཱལ་ཝ་ཌོར།',
	'TD' => 'ཅཻཌ།',
	'TR' => 'ཏུརཀི།',
	'TV' => 'ཐུ་ཝ་ལུ།',
	'UA' => 'ཡུ་ཀྲན།',
	'UG' => 'ཡུ་གན་ཌ།',
	'US' => 'ཨ་མེ་རི་ཀ།',
	'UY' => 'ཨུ་རུ་གྷེ།',
	'UZ' => 'ཨུཛ་བེ་ཀིསྟཱན།',
	'VA' => 'ཝེ་ཊི་ཀན།',
	'VC' => 'སེནྚ། ཝིན་སན། དང༌། གྷིརིན་ཌིན།',
	'VE' => 'ཝེ་ནི་ཛུའེ་ལ།',
	'VN' => 'བི་དི་ནམ།',
	'VU' => 'ཝ་ནུ་ཨ་ཐུ།',
	'WS' => 'ནུ་བ་ས་མོ་འ།',
	'YE' => 'ཡེ་མེན།',
	'ZA' => 'ལྷོ་ ཨཕྲི་ཀ།',
	'ZM' => 'ཛམ་བི་ཡ།',
	'ZW' => 'ཛིམ་བྷཱ་བེ།',
);
